**To get a description of your namespace**

The following ``describe-namespace`` example gets a description of your namespace. ::

    aws iotthingsgraph describe-namespace

Output::

    {
        "namespaceName": "us-west-2/123456789012/default",
        "trackingNamespaceName": "aws",
        "trackingNamespaceVersion": 1,
        "namespaceVersion": 5
    }

For more information, see `Namespaces <https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-whatis-namespace.html>`__ in the *AWS IoT Things Graph User Guide*.
